#include "i2c1.h"

void initI2C1()
{
	RCC_APB1ENR |= BIT21; // Turn in clock for I2C1
	RCC_AHBENR |= BIT18; // Turn on the clock for GPIOB
	GPIOB_MODER |= BIT13+BIT15; // Enable alternate function on bit 6 and 7 port b
	GPIOB_MODER &=~ ( BIT12+BIT14);
	GPIOB_AFRL |= BIT30+BIT26; // Select alternate function for I2C1 for port b
	I2C1_CR1 = 0;
	delay(100);
	I2C1_CR2 = 0x00010000+BIT10;
	//I2C clock = 8MHZ Pre-scaler =15, I2C speed approx 88.888kHz
	I2C1_TIMINGR = 0xE0000303; 
	I2C1_CR1 = BIT0;
	
}
void ResetI2C()
{
	I2C1_CR1 &= ~BIT0;
	while(I2C1_CR1 & BIT0); // forces a wait.
	I2C1_CR1 = BIT0;
}
void I2CStart(uint8_t address, int rw, int nbytes)
{
	unsigned timeout;
	unsigned Reg;
	Reg = I2C1_CR2;
	Reg &= ~BIT13; // clear START bit
	// Clear out old address.
	Reg &= ~(0x3ff); // clear out lower 10 bits of CR1 (address)
	Reg |= (address & 0x3ff); // set address bits
	if (rw==READ)
		Reg |= BIT10; // read mode so set read bit
	else
		Reg &= ~BIT10; // write mode
	Reg &= ~(0x00ff0000); // clear byte count
	Reg |= (nbytes << 16); // set byte count
	Reg |= BIT24; // set reload bit
	Reg |= BIT13; // set START bit
	I2C1_CR2 = Reg;
	timeout=I2C_TIMEOUT;
	while((timeout--)&&!(I2C1_ISR & BIT0)); // wait for transmit complete
}
void I2CReStart(uint8_t address, int rw, int nbytes)
{
	unsigned timeout;
	unsigned Reg;
	Reg = I2C1_CR2;
	Reg &= ~BIT13; // clear START bit
	// Clear out old address.
	Reg &= ~(0x3ff); // clear out lower 10 bits of CR1 (address)
	Reg |= (address & 0x3ff); // set address bits
	if (rw==READ)
		Reg |= BIT10; // read mode so set read bit
	else
		Reg &= ~BIT10; // write mode
	Reg &= ~(0x00ff0000); // clear byte count
	Reg |= (nbytes << 16); // set byte count
	Reg &= ~BIT24; // set reload bit
	Reg |= BIT13; // set START bit
	I2C1_CR2 = Reg;
	timeout=I2C_TIMEOUT;
	while((timeout--)&&!(I2C1_ISR & BIT0)); // wait for transmit complete
}
void I2CStop()
{
	I2C1_CR2 &= ~BIT24; // clear reload bit
	delay(10);
	I2C1_CR2 |= BIT14;	// set stop bit
	delay(100);
}

void I2CWrite(uint8_t Data)
{
	unsigned timeout;
	//I2C1_CR2 &= ~BIT10; // write mode
	
	//delay(100);
	I2C1_TXDR = Data;
	delay(100);
	timeout = I2C_TIMEOUT;
	while((timeout--)&&((I2C1_ISR & (BIT0+BIT6))==0)); // wait for transmit complete
	delay(100);
}
uint8_t I2CRead()
{
	unsigned timeout;
	//I2C1_CR2 |= BIT10; 		// read mode
	//I2C1_TXDR = 0xff;		// send a dummy byte
	timeout = I2C_TIMEOUT;
	while((timeout--)&&!(I2C1_ISR & BIT2)); // wait for receive complete
	return I2C1_RXDR; 		// return rx data
}
