// implementation for LSM303DLHC Accelerometer/compass
#include "lsm303dlhc.h"
void WriteLSM303(int DeviceAddress,uint8_t SubAddress,uint8_t Data);
uint8_t ReadLSM303(int DeviceAddress,uint8_t SubAddress);

void WriteAccelRegister(uint8_t SubAddress, uint8_t Data)
{
	WriteLSM303(ACCEL_ADDRESS,SubAddress,Data);
}
uint8_t ReadAccelRegister(uint8_t SubAddress)
{
	ReadLSM303(ACCEL_ADDRESS,SubAddress);
}

void WriteCompassRegister(uint8_t SubAddress, uint8_t Value)
{
	WriteLSM303(COMPASS_ADDRESS,SubAddress,Value);
}
uint8_t ReadCompassRegister(uint8_t SubAddress )
{
	return ReadLSM303(COMPASS_ADDRESS,SubAddress);
}


void WriteLSM303(int DeviceAddress, uint8_t address, uint8_t Data)
{
	ResetI2C();
	unsigned timeout;
	unsigned Reg;
	Reg = I2C1_CR2;
	Reg &= ~BIT13; // clear START bit
	// Clear out old address.
	Reg &= ~(0x3ff67ff); // clear out lower 10 bits of CR2 (address)
	Reg |= (DeviceAddress & 0x3ff); // set address bits
	Reg &= ~BIT10; // write mode
	Reg &= ~(0x00ff0000); // clear byte count
	Reg |= (1 << 16); // set byte count
	Reg |= BIT24; // set reload bit
	Reg |= BIT13; // set START bit
	I2C1_CR2 = Reg;
	timeout=I2C_TIMEOUT;
	Reg=I2C1_CR2;
	Reg=I2C1_ISR;
	while((timeout--)&&!(Reg & BIT1)) // wait for TXIS
		Reg=I2C1_ISR; // wait for transmit complete
	I2C1_TXDR = address; // send sub address
	timeout = I2C_TIMEOUT;
	Reg=I2C1_ISR;
	while((timeout--)&&((Reg & (BIT7))==0)) // wait for tcr
		Reg=I2C1_ISR; 
	
	Reg = I2C1_CR2;
	Reg &= ~BIT13; // clear START bit
	// Clear out old address.
	Reg &= ~(0x3ff67ff); // clear out lower 10 bits of CR2 (address)
	Reg |= (DeviceAddress & 0x3ff); // set address bits
	Reg &= ~BIT10; // write mode
	Reg &= ~(0x00ff0000); // clear byte count
	Reg |= (1 << 16); // set byte count
	Reg &= ~BIT24;// clear reload
	Reg |= BIT25; // Auto end mode
	
	I2C1_CR2 = Reg;
	Reg = I2C1_ISR;
	while((timeout--)&&((Reg & (BIT1))==0)) // wait for txis
		Reg = I2C1_ISR;
	I2C1_TXDR = Data;
	timeout = I2C_TIMEOUT;
	while((timeout--)&&((I2C1_ISR & (BIT6))==0)); // wait for tc

}
uint8_t ReadLSM303(int DeviceAddress, uint8_t address)
{
	uint8_t RValue;
	ResetI2C();
	unsigned timeout;
	unsigned Reg;
	Reg = I2C1_CR2;
	Reg &= ~BIT13; // clear START bit
	// Clear out old address.
	Reg &= ~(0x3ff67ff); // clear out lower 10 bits of CR2 (address)
	Reg |= (DeviceAddress & 0x3ff); // set address bits
	Reg &= ~BIT10; // write mode
	Reg &= ~(0x00ff0000); // clear byte count
	Reg |= (1 << 16); // set byte count
	//Reg |= BIT24; // set reload bit
	Reg |= BIT13; // set START bit
	I2C1_CR2 = Reg;
	timeout=I2C_TIMEOUT;
	Reg=I2C1_CR2;
	Reg=I2C1_ISR;
	while((timeout--)&&!(Reg & BIT1)) // wait for TXIS
		Reg=I2C1_ISR; // wait for transmit complete
	I2C1_TXDR = address; // send sub address
	timeout = I2C_TIMEOUT;
	Reg=I2C1_ISR;
	while((timeout--)&&((Reg & (BIT6))==0)) // wait for tc
		Reg=I2C1_ISR; 
	
	Reg = I2C1_CR2;
	Reg &= ~BIT13; // clear START bit
	// Clear out old address.
	Reg &= ~(0x3ff67ff); // clear out lower 10 bits of CR2 (address)
	Reg |= (DeviceAddress & 0x3ff); // set address bits
	Reg |= BIT10; // read mode
	Reg &= ~(0x00ff0000); // clear byte count
	Reg |= (1 << 16); // set byte count
	Reg &= ~BIT24;// clear reload
	Reg |= BIT25; // Auto end mode
	Reg |= BIT13; // re-start bit
	I2C1_CR2 = Reg;
	Reg = I2C1_ISR;
	while((timeout--)&&((Reg & (BIT1))==0)) // wait for txis
		Reg = I2C1_ISR;
	RValue=I2C1_RXDR;
	timeout = I2C_TIMEOUT;
	Reg = I2C1_ISR;
	while((timeout--)&&((Reg & (BIT2))==0))
		Reg = I2C1_ISR; // wait for tc
	RValue=I2C1_RXDR;
	return RValue;	
}
