
#include "stm32f303xx.h"
#include "i2c1.h"
#include "lsm303dlhc.h"
void delay(int);

void delay(int dly)
{
  while( dly--);
}

void configPins()
{
	// Power up PORTE, PORTA	
	RCC_AHBENR |= BIT21+BIT17;
	// Make PORTE LED bits outputs
	GPIOE_MODER |= BIT30+BIT28+BIT26+BIT24+BIT22+BIT20+BIT18+BIT16;
}
void initClock()
{
	// Assumption: Using HSE clock (8MHz)
	// This clock is provided by the STLink debug interface
	// PLL is driven by HSE = 8MHz
	// Multiply x 9 = 72MHz
	
	// Must set flash latency (2 wait states) to allow
	// for higher speed clock	
	FLASH_ACR |= 2; // add two wait states
	
	RCC_CR &= ~BIT24; // turn off PLL
	delay(10);	
	RCC_CFGR |= ((0x07) << 18);	// PLL multiply = 9
	RCC_CFGR |= BIT16;  // select HSE as PLL input
	RCC_CFGR |= BIT10;  // APB1 Clock = HCLK/2 (36MHz)
	RCC_CR |= BIT18 + BIT16; // Turn on HSE and set HSEBYP
	delay(10);
	RCC_CR |= BIT24; // turn on PLL
	delay(10);
	RCC_CFGR |= BIT1;  // switch to PLL as clock
}

int main()
{	

	int yaccel;
	int ycompass;
	int temperature;
	int status;
	initClock();
	initI2C1();
	configPins();
	initUART(9600);
		
	WriteAccelRegister(CTRL_REG1_A,0x77); // power up the accelerometer
		
	WriteCompassRegister(CRA_REG_M,0x9c); // max speed mag reading.
									      // temp sensor on.									      
	WriteCompassRegister(CRB_REG_M,0x20); // max speed mag reading.
									      // temp sensor on.
	WriteCompassRegister(MR_REG_M,0x00); // exit sleep mode
	 
	//while(1)
	{
		//WriteAccelRegister(CTRL_REG1_A,0x77); // power up the accelerometer
		status=ReadAccelRegister(CTRL_REG1_A);

		yaccel = ReadAccelRegister(OUT_Y_H_A);
		yaccel = yaccel << 8;
		yaccel = yaccel + (int)ReadAccelRegister(OUT_Y_L_A);
		
		eputShort(status);
		eputs(",");
		eputShort(yaccel);
		eputs("\n");
		
		delay(100000);
	}
	
	eputs("Ready\r\n");
	while(1)
	{			
		yaccel = ReadAccelRegister(OUT_Y_H_A);
		yaccel = yaccel << 8;
		yaccel = yaccel + (int)ReadAccelRegister(OUT_Y_L_A);
		eputShort(yaccel);
		eputs(","); 
			    ycompass = ReadCompassRegister(OUT_X_H_M);
		ycompass = ycompass << 8;
		ycompass = ycompass + ReadCompassRegister(OUT_X_L_M);
			    ycompass = ReadCompassRegister(OUT_Y_H_M);
		ycompass = ycompass << 8;
		ycompass = ycompass + ReadCompassRegister(OUT_Y_L_M);
	    ycompass = ReadCompassRegister(OUT_Z_H_M);
		ycompass = ycompass << 8;
		ycompass = ycompass + ReadCompassRegister(OUT_Z_L_M);
		eputShort(ycompass);
		eputs(","); 
		temperature = ReadCompassRegister(TEMP_OUT_H_M);
		temperature = temperature << 8;
		temperature = temperature + ReadCompassRegister(TEMP_OUT_L_M);		
		eputShort(temperature);
		eputs("\n");	
		
		delay(100000);
	} 
	return 0;
}








